@@ -2,3 +2,7 @@
 def run():
     import pyinstaller_dump
     pyinstaller_dump.run()
+
+
+if __name__ == '__main__':
+    run()
